% Computing and visualizing density, thermal expansion and compressibility
% for periclase (MgO) based on its Gibbs free energy equation 




% Clearing all variables and arrays
clear all;
% Clearing figures
clf;

%P GPa
pmin=4;
pstp=4;
pmax=100; 
% T K
tmin=75;
tstp=75;
tmax=3000;

% Compute Gibbs free energy G of periclase for P=1-100 GPa and T=100-4000 K
i=0; %P index
for P=pmin:pstp:pmax %P GPa
    i=i+1; %P index
    j=0; %T index
    for T=tmin:tstp:tmax % T K
        j=j+1; %T index
        % Computing Gibbs free energy J/mol
        % with an external function G_periclase()
        G(i,j)=G_periclase(P*1e+9,T);
    end
end

% Compute density RHO of periclase for P=1-100 GPa and T=100-4000 K
% RHO=m/V where m is molar mass and V is molar volume
% V=dG/dP - can be computed by using differences instead of derivatives
% i.e. V=(G(P+dP,T)-G(P,T))/dP where dP is small increment in pressure
% molar mass of periclase
m=0.0403044; % kg/mol
i=0; %P index
for P=pmin:pstp:pmax %P GPa
    i=i+1; %P index
    j=0; %T index
    for T=tmin:tstp:tmax % T K
        j=j+1; %T index
        % Computing Gibbs free energy J/mol
        % with an external function G_periclase()
        % Define small increment for Pressure (GPa)
        dP=P*1e-4;
        % Computing molar volume
        V=(G_periclase((P+dP)*1e+9,T)-G_periclase(P*1e+9,T))/(dP*1e+9);
        % Computing density
        RHO(i,j)=m/V;
    end
end

% Compute thermal expansion ALPHA of periclase for P=1-100 GPa and T=100-4000 K
% ALPHA=-1/RHO*dRHO/dT can be computed by using differences instead of derivatives
% i.e. ALPHA=-1/RHO*(RHO(P,T+dT)-RHO(P,T))/dT where dT is small increment in temperature
i=0; %P index
for P=pmin:pstp:pmax %P GPa
    i=i+1; %P index
    j=0; %T index
    for T=tmin:tstp:tmax % T K
        j=j+1; %T index
        % Computing Gibbs free energy J/mol
        % with an external function G_periclase()
        % Define small increment for Temperature (K)
        dT=T*1e-4;
        
        % Compute RHO(P,T+dT)
        % RHO=m/V where m is molar mass and V is molar volume
        % V=dG/dP - can be computed by using differences instead of derivatives
        % i.e. V=(G(P+dP,T)-G(P,T))/dP where dP is small increment in pressure
        % Define small increment for Pressure (GPa)
        dP=P*1e-4;
        % Computing molar volume
        V=(G_periclase((P+dP)*1e+9,T+dT)-G_periclase(P*1e+9,T+dT))/(dP*1e+9);
        % Computing density
        RHO2=m/V;
        
        % Compute ALPHA 1/K
        ALPHA(i,j)=-1/RHO(i,j)*(RHO2-RHO(i,j))/dT;
        
    end
end

% Compute compressibility BETTA of periclase for P=1-100 GPa and T=100-4000 K
% BETTA=-1/RHO*dRHO/dP can be computed by using differences instead of derivatives
% i.e. BETTA=-1/RHO*(RHO(P+dP,T)-RHO(P,T))/dP where dP is small increment in pressure
i=0; %P index
for P=pmin:pstp:pmax %P GPa
    i=i+1; %P index
    j=0; %T index
    for T=tmin:tstp:tmax % T K
        j=j+1; %T index
        % Computing Gibbs free energy J/mol
        % with an external function G_periclase()
        % Define small increment for Pressure (GPa)
        dP=P*1e-4;
        % Compute incremented pressure value P1=P+dP
        P1=P+dP;
        
        % Compute RHO(P1,T) 
        % RHO=m/V where m is molar mass and V is molar volume
        % V=dG/dP - can be computed by using differences instead of derivatives
        % i.e. V=(G(P1+dP,T)-G(P1,T))/dP where dP is small increment in pressure
        % Define small increment for Pressure (GPa)
        dP=P*1e-4;
        % Computing molar volume
        V=(G_periclase((P1+dP)*1e+9,T)-G_periclase(P1*1e+9,T))/(dP*1e+9);
        % Computing density
        RHO2=m/V;
        
        % Compute BETTA 1/Pa
        BETTA(i,j)=1/RHO(i,j)*(RHO2-RHO(i,j))/(dP*1e+9);
        
    end
end




% Creating a vector of arguments for horizontal T axis
T=tmin:tstp:tmax; % T K
% Creating a vector of arguments for vertical P axis
P=pmin:pstp:pmax; %P GPa

% 2D plot
% Defining new figure
figure(1)
% Plotting Gibbs free energy kJ/mol
subplot(2,2,1);     % defining 2nd plotting area in the 3x1 figure
pcolor(T,P,G*1e-3);      % making colormap
box on;             % making box around the plot
title('Gibbs free energy kJ/mol');   % title of the plot
xlabel('T K');        % title of horizontal axis
ylabel('P GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map
hold on;            % continuing plotting on the colormap 
[C, h] = contour (T,P,G*1e-3,'k');   % drawing isolines
clabel(C,h,'Color','k');        % labelling isolines
hold off;           % stop plotting on the colormap

% Plotting density kg/m^3
subplot(2,2,2);     % defining 2nd plotting area in the 3x1 figure
pcolor(T,P,RHO);      % making colormap
box on;             % making box around the plot
title('density kg/m^3');   % title of the plot
xlabel('T K');        % title of horizontal axis
ylabel('P GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map
hold on;            % continuing plotting on the colormap 
[C, h] = contour (T,P,RHO,'k');   % drawing isolines
clabel(C,h,'Color','k');        % labelling isolines
hold off;           % stop plotting on the colormap

% Plotting ALPHA 1/K
subplot(2,2,3);     % defining 2nd plotting area in the 3x1 figure
pcolor(T,P,ALPHA);      % making colormap
box on;             % making box around the plot
title('thermal expansion 1/K');   % title of the plot
xlabel('T K');        % title of horizontal axis
ylabel('P GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map
hold on;            % continuing plotting on the colormap 
[C, h] = contour (T,P,ALPHA,'k');   % drawing isolines
clabel(C,h,'Color','k');        % labelling isolines
hold off;           % stop plotting on the colormap

% Plotting BETTA 1/GPa
subplot(2,2,4);     % defining 2nd plotting area in the 3x1 figure
pcolor(T,P,BETTA*1e+9);      % making colormap
box on;             % making box around the plot
title('compressibility 1/GPa');   % title of the plot
xlabel('T K');        % title of horizontal axis
ylabel('P GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map
hold on;            % continuing plotting on the colormap 
[C, h] = contour (T,P,BETTA*1e+9,'k');   % drawing isolines
clabel(C,h,'Color','k');        % labelling isolines
hold off;           % stop plotting on the colormap

% 3D plot
% Defining new figure
figure(2); colormap('Jet'); clf
% Plotting Gibbs free energy kJ/mol
subplot(2,2,1);     % defining 2nd plotting area in the 3x1 figure
surf(T,P,G*1e-3);      % making colormap
box on;             % making box around the plot
title('Gibbs free energy, kJ/mol');   % title of the plot
xlabel('T, K');        % title of horizontal axis
ylabel('P, GPa');        % title of vertical axis
%shading interp;     % making smooth transitions between colors
% colorbar;           % showing colorbar for the map
% light;              % shedding light to the surface
% lighting phong;     % making nicely reflecting surface
box on
axis([0 3000 0 100 -1000 500])
ax=gca;
ax.TickDir='out';
ax.LineWidth=1.5;
ax.XTick=[0 1000 2000 3000];
ax.YTick=[0 50 100];
ax.ZTick=[-1000 -500 0 500];
ax.FontName='Serif';
ax.FontSize=20;
ax.FontWeight='bold';


% Plotting density kg/m^3
subplot(2,2,2);     % defining 2nd plotting area in the 3x1 figure
surf(T,P,RHO);      % making colormap
box on;             % making box around the plot
title('density, kg/m^3');   % title of the plot
xlabel('T, K');        % title of horizontal axis
ylabel('P, GPa');        % title of vertical axis
%shading interp;     % making smooth transitions between colors
% colorbar;           % showing colorbar for the map
% light;              % shedding light to the surface
% lighting phong;     % making nicely reflecting surface
box on
axis([0 3000 0 100 3000 5000])
ax=gca;
ax.TickDir='out';
ax.LineWidth=1.5;
ax.XTick=[0 1000 2000 3000];
ax.YTick=[0 50 100];
ax.ZTick=[3000 4000 5000];
ax.FontName='Serif';
ax.FontSize=20;
ax.FontWeight='bold';

% Plotting ALPHA 1/K
subplot(2,2,3);     % defining 2nd plotting area in the 3x1 figure
surf(T,P,ALPHA*1e5);      % making colormap
box on;             % making box around the plot
title('thermal expansion, 10^-^5 1/K');   % title of the plot
xlabel('T, K');        % title of horizontal axis
ylabel('P, GPa');        % title of vertical axis
%shading interp;     % making smooth transitions between colors
% colorbar;           % showing colorbar for the map
% light;              % shedding light to the surface
% lighting phong;     % making nicely reflecting surface
axis ij;
box on
axis([0 3000 0 100 0 6])
ax=gca;
ax.TickDir='out';
ax.LineWidth=1.5;
ax.XTick=[0 1000 2000 3000];
ax.YTick=[0 50 100];
ax.ZTick=[0 2 4 6];
ax.FontName='Serif';
ax.FontSize=20;
ax.FontWeight='bold';

% Plotting BETTA 1/GPa
subplot(2,2,4);     % defining 2nd plotting area in the 3x1 figure
surf(T,P,BETTA*1e+9);      % making colormap
box on;             % making box around the plot
title('compressibility, 1/GPa');   % title of the plot
xlabel('T, K');        % title of horizontal axis
ylabel('P, GPa');        % title of vertical axis
%shading interp;     % making smooth transitions between colors
% colorbar;           % showing colorbar for the map
% light;              % shedding light to the surface
% lighting phong;     % making nicely reflecting surface
axis ij;
box on
axis([0 3000 0 100 0 0.010])
ax=gca;
ax.TickDir='out';
ax.LineWidth=1.5;
ax.XTick=[0 1000 2000 3000];
ax.YTick=[0 50 100];
ax.ZTick=[0 0.005 0.010];
ax.FontName='Serif';
ax.FontSize=20;
ax.FontWeight='bold';
pause(.1)

print ('-djpeg', '-r300','eos');





